@@ -7,7 +7,7 @@ import warnings
 
 import numpy as np
 import scipy.stats as stats
-from sklearn.cluster import KMeans as KMEANS
+from sklearn.cluster import KMeans
 
 __author__ = "Sergio J. Rey"
 
@@ -67,7 +67,7 @@ try:
 except ImportError:
     HAS_NUMBA = False
 
-    def njit(type, cache):
+    def njit(_type):  # noqa ARG001
         def decorator_njit(func):
             @functools.wraps(func)
             def wrapper_decorator(*args, **kwargs):
@@ -108,17 +108,16 @@ def _format_intervals(mc, fmt="{:.0f}"):
     For some classifiers, it is possible that the upper bound of the first
     interval is less than the minimum value of the attribute that is being
     classified. In these cases ``lower_open=True`` and the lower bound of the
-    interval is set to ``numpy.NINF```.
+    interval is set to ``numpy.NINF``.
 
     """
 
     lowest = mc.y.min()
-    if hasattr(mc, "lowest"):
-        if mc.lowest is not None:
-            lowest = mc.lowest
+    if hasattr(mc, "lowest") and mc.lowest is not None:
+        lowest = mc.lowest
     lower_open = False
     if lowest > mc.bins[0]:
-        lowest = np.NINF
+        lowest = -np.inf
         lower_open = True
     edges = [lowest]
     edges.extend(mc.bins)
@@ -258,11 +257,12 @@ def quantile(y, k=4):
             f"Not enough unique values in array to form {k} classes. "
             f"Setting k to {k_q}.",
             UserWarning,
+            stacklevel=2,
         )
     return q
 
 
-def binC(y, bins):
+def binC(y, bins):  # noqa N802
     """
     Bin categorical/qualitative data.
 
@@ -315,25 +315,29 @@ def binC(y, bins):
 
     """
 
+    # TODO: consider renaming ``binC`` to ``bin_c`` to resolve N802 (gh#185)
+
     if np.ndim(y) == 1:
         k = 1
         n = np.shape(y)[0]
     else:
         n, k = np.shape(y)
     b = np.zeros((n, k), dtype="int")
-    for i, bin in enumerate(bins):
-        b[np.nonzero(y == bin)] = i
+    for i, _bin in enumerate(bins):
+        b[np.nonzero(y == _bin)] = i
 
     # check for non-binned items and warn if needed
     vals = set(y.flatten())
     for val in vals:
         if val not in bins:
-            warnings.warn(f"\nValue not in bin: {val}\nBins: {bins}", UserWarning)
+            warnings.warn(
+                f"\nValue not in bin: {val}\nBins: {bins}", UserWarning, stacklevel=2
+            )
 
     return b
 
 
-def bin(y, bins):
+def bin(y, bins):  # noqa A001
     """
     Bin interval/ratio data.
 
@@ -385,6 +389,9 @@ def bin(y, bins):
            [0, 0, 2]])
 
     """
+
+    # TODO: consider renaming ``bin`` to ``bin_int`` to resolve A001 (gh#185)
+
     if np.ndim(y) == 1:
         k = 1
         n = np.shape(y)[0]
@@ -392,7 +399,7 @@ def bin(y, bins):
         n, k = np.shape(y)
     b = np.zeros((n, k), dtype="int")
     i = len(bins)
-    if type(bins) != list:
+    if not isinstance(bins, list):
         bins = bins.tolist()
     binsc = copy.copy(bins)
     while binsc:
@@ -438,7 +445,7 @@ def bin1d(x, bins):
            1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
            2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2])
 
-    >>> list(counts)
+    >>> counts.tolist()
     [26, 49, 25]
 
     """
@@ -450,8 +457,8 @@ def bin1d(x, bins):
     binIds = np.zeros(x.shape, dtype="int")
     while cuts:
         k -= 1
-        l, r = cuts.pop(-1)
-        binIds += (x > l) * (x <= r) * k
+        _l, r = cuts.pop(-1)
+        binIds += (x > _l) * (x <= r) * k
     counts = np.bincount(binIds, minlength=len(bins))
     return (binIds, counts)
 
@@ -516,9 +523,9 @@ def _kmeans(y, k=5, n_init=10):
 
     """
 
-    y = y * 1.0  # KMEANS needs float or double dtype
+    y = y * 1.0  # sklearn.cluster.KMeans needs float or double dtype
     y.shape = (-1, 1)
-    result = KMEANS(n_clusters=k, init="k-means++", n_init=n_init).fit(y)
+    result = KMeans(n_clusters=k, init="k-means++", n_init=n_init).fit(y)
     class_ids = result.labels_
     centroids = result.cluster_centers_
     binning = []
@@ -562,6 +569,7 @@ def natural_breaks(values, k=5, init=10):
             f"Not enough unique values in array to form {k} classes. "
             f"Setting k to {uvk}.",
             UserWarning,
+            stacklevel=2,
         )
         k = uvk
     kres = _kmeans(values, k, n_init=init)
@@ -572,7 +580,7 @@ def natural_breaks(values, k=5, init=10):
     return (sids, class_ids, fit, cuts)
 
 
-@njit("f8[:](f8[:], u2)", cache=True)
+@njit("f8[:](f8[:], u2)")
 def _fisher_jenks_means(values, classes=5):
     """
     Jenks Optimal (Natural Breaks) algorithm implemented in Python.
@@ -623,13 +631,13 @@ def _fisher_jenks_means(values, classes=5):
     kclass[0] = values[0]
     for countNum in range(classes, 1, -1):
         pivot = mat1[k, countNum]
-        id = int(pivot - 2)
-        kclass[countNum - 1] = values[id]
+        _id = int(pivot - 2)
+        kclass[countNum - 1] = values[_id]
         k = int(pivot - 1)
     return np.delete(kclass, 0)
 
 
-class MapClassifier(object):
+class MapClassifier:
     r"""
     Abstract class for all map classifications :cite:`Slocum_2009`
 
@@ -909,7 +917,7 @@ class MapClassifier(object):
         fmt = self.fmt
         return _get_table(self, fmt=fmt)
 
-    def __call__(self, *args, **kwargs):
+    def __call__(self, *args):
         """
         This will allow the classifier to be called like it's a function.
 
@@ -957,10 +965,8 @@ class MapClassifier(object):
     def get_gadf(self):
         """Goodness of absolute deviation of fit."""
         adam = (np.abs(self.y - np.median(self.y))).sum()
-        if adam == 0:  # array is invariant
-            gadf = 1
-        else:
-            gadf = 1 - self.adcm / adam
+        # return 1 if array is invariant
+        gadf = 1 if adam == 0 else 1 - self.adcm / adam
         return gadf
 
     def find_bin(self, x):
@@ -1091,7 +1097,7 @@ class MapClassifier(object):
                 "Mapclassify.plot depends on matplotlib.pyplot, and this was"
                 "not able to be imported. \nInstall matplotlib to"
                 "plot spatial classifier."
-            )
+            ) from None
         if ax is None:
             f = plt.figure()
             ax = plt.gca()
@@ -1150,7 +1156,7 @@ class HeadTailBreaks(MapClassifier):
     >>> htb.k
     3
 
-    >>> list(htb.counts)
+    >>> htb.counts.tolist()
     [50, 7, 1]
 
     >>> htb.bins
@@ -1163,7 +1169,7 @@ class HeadTailBreaks(MapClassifier):
     array([ 32.26204423,  72.50205622, 128.07150107, 190.2899093 ,
            264.82847377, 457.88157946, 576.76046949])
 
-    >>> list(htb.counts)
+    >>> htb.counts.tolist()
     [695, 209, 62, 22, 10, 1, 1]
 
     Notes
@@ -1227,7 +1233,7 @@ class EqualInterval(MapClassifier):
     >>> ei.k
     5
 
-    >>> list(ei.counts)
+    >>> ei.counts.tolist()
     [57, 0, 0, 0, 1]
 
     >>> ei.bins
@@ -1309,14 +1315,14 @@ class Percentiles(MapClassifier):
     array([1.357000e-01, 5.530000e-01, 9.365000e+00, 2.139140e+02,
            2.179948e+03, 4.111450e+03])
 
-    >>> list(p.counts)
+    >>> p.counts.tolist()
     [1, 5, 23, 23, 5, 1]
 
     >>> p2 = mapclassify.Percentiles(cal, pct = [50, 100])
     >>> p2.bins
     array([   9.365, 4111.45 ])
 
-    >>> list(p2.counts)
+    >>> p2.counts.tolist()
     [29, 29]
     >>> p2.k
     2
@@ -1453,10 +1459,10 @@ class BoxPlot(MapClassifier):
     array([-5.287625e+01,  2.567500e+00,  9.365000e+00,  3.953000e+01,
             9.497375e+01,  4.111450e+03])
 
-    >>> list(bp.counts)
+    >>> bp.counts.tolist()
     [0, 15, 14, 14, 6, 9]
 
-    >>> list(bp.high_outlier_ids)
+    >>> bp.high_outlier_ids.tolist()
     [0, 6, 18, 29, 33, 36, 37, 40, 42]
 
     >>> cal[bp.high_outlier_ids].values
@@ -1570,7 +1576,7 @@ class Quantiles(MapClassifier):
     >>> q.bins
     array([1.46400e+00, 5.79800e+00, 1.32780e+01, 5.46160e+01, 4.11145e+03])
 
-    >>> list(q.counts)
+    >>> q.counts.tolist()
     [12, 11, 12, 11, 12]
 
     """
@@ -1637,7 +1643,7 @@ class StdMean(MapClassifier):
     array([-967.36235382, -420.71712519,  672.57333208, 1219.21856072,
            4111.45      ])
 
-    >>> list(st.counts)
+    >>> st.counts.tolist()
     [0, 0, 56, 1, 1]
 
     >>> st3 = mapclassify.StdMean(cal, multiples = [-3, -1.5, 1.5, 3])
@@ -1645,7 +1651,7 @@ class StdMean(MapClassifier):
     array([-1514.00758246,  -694.03973951,   945.8959464 ,  1765.86378936,
             4111.45      ])
 
-    >>> list(st3.counts)
+    >>> st3.counts.tolist()
     [0, 0, 57, 0, 1]
     >>> stda = mapclassify.StdMean(cal, anchor=True)
     >>> stda.k
@@ -1654,7 +1660,7 @@ class StdMean(MapClassifier):
     array([ 125.92810345,  672.57333208, 1219.21856072, 1765.86378936,
            2312.50901799, 2859.15424663, 3405.79947527, 3952.4447039 ,
            4111.45      ])
-    >>> cal.mean(), cal.std(), cal.min(), cal.max()
+    >>> float(cal.mean()), float(cal.std()), float(cal.min()), float(cal.max())
     (125.92810344827588, 546.6452286365233, 0.13, 4111.45)
     """
 
@@ -1744,7 +1750,7 @@ class MaximumBreaks(MapClassifier):
     >>> mb.bins
     array([ 146.005,  228.49 ,  546.675, 2417.15 , 4111.45 ])
 
-    >>> list(mb.counts)
+    >>> mb.counts.tolist()
     [50, 2, 4, 1, 1]
 
     """
@@ -1771,7 +1777,9 @@ class MaximumBreaks(MapClassifier):
         ud = np.unique(diffs)
         if len(ud) < k1:
             warnings.warn(
-                "Insufficient number of unique diffs. Breaks are random.", UserWarning
+                "Insufficient number of unique diffs. Breaks are random.",
+                UserWarning,
+                stacklevel=3,
             )
         mp = []
         for c in range(1, k):
@@ -1847,7 +1855,7 @@ class NaturalBreaks(MapClassifier):
     >>> nb.k
     5
 
-    >>> list(nb.counts)
+    >>> nb.counts.tolist()
     [49, 3, 4, 1, 1]
 
     >>> nb.bins
@@ -1872,6 +1880,7 @@ class NaturalBreaks(MapClassifier):
                 f"Not enough unique values in array to form {k} classes. "
                 f"Setting k to {uvk}.",
                 UserWarning,
+                stacklevel=3,
             )
             k = uvk
             uv.sort()
@@ -1940,13 +1949,13 @@ class FisherJenks(MapClassifier):
     >>> import mapclassify
     >>> cal = mapclassify.load_example()
     >>> fj = mapclassify.FisherJenks(cal)
-    >>> fj.adcm
+    >>> float(fj.adcm)
     799.24
 
-    >>> list(fj.bins)
+    >>> fj.bins.tolist()
     [75.29, 192.05, 370.5, 722.85, 4111.45]
 
-    >>> list(fj.counts)
+    >>> fj.counts.tolist()
     [49, 3, 4, 1, 1]
 
     """
@@ -1954,7 +1963,9 @@ class FisherJenks(MapClassifier):
     def __init__(self, y, k=K):
         if not HAS_NUMBA:
             warnings.warn(
-                "Numba not installed. Using slow pure python version.", UserWarning
+                "Numba not installed. Using slow pure python version.",
+                UserWarning,
+                stacklevel=3,
             )
 
         nu = len(np.unique(y))
@@ -2095,7 +2106,7 @@ class JenksCaspall(MapClassifier):
     >>> jc.bins
     array([1.81000e+00, 7.60000e+00, 2.98200e+01, 1.81270e+02, 4.11145e+03])
 
-    >>> list(jc.counts)
+    >>> jc.counts.tolist()
     [14, 13, 14, 10, 7]
 
     """
@@ -2181,10 +2192,10 @@ class JenksCaspallSampled(MapClassifier):
     >>> jcs.bins
     array([0.19978245, 0.40793025, 0.59253555, 0.78241472, 0.99997795])
 
-    >>> list(jc.counts)
+    >>> jc.counts.tolist()
     [20286, 19951, 20310, 19708, 19745]
 
-    >>> list(jcs.counts)
+    >>> jcs.counts.tolist()
     [20147, 20633, 18591, 18857, 21772]
 
     # not for testing since we get different times on different hardware
@@ -2292,7 +2303,7 @@ class JenksCaspallForced(MapClassifier):
     >>> jcf.bins
     array([1.34000e+00, 5.90000e+00, 1.67000e+01, 5.06500e+01, 4.11145e+03])
 
-    >>> list(jcf.counts)
+    >>> jcf.counts.tolist()
     [12, 12, 13, 9, 12]
 
     >>> jcf4 = mapclassify.JenksCaspallForced(cal, k=4)
@@ -2302,7 +2313,7 @@ class JenksCaspallForced(MapClassifier):
     >>> jcf4.bins
     array([2.51000e+00, 8.70000e+00, 3.66800e+01, 4.11145e+03])
 
-    >>> list(jcf4.counts)
+    >>> jcf4.counts.tolist()
     [15, 14, 14, 15]
 
     """
@@ -2444,18 +2455,18 @@ class UserDefined(MapClassifier):
     [20, 4111.45]
 
     >>> ud = mapclassify.UserDefined(cal, bins)
-    >>> list(ud.bins)
+    >>> ud.bins.tolist()
     [20.0, 4111.45]
 
-    >>> list(ud.counts)
+    >>> ud.counts.tolist()
     [37, 21]
 
     >>> bins = [20, 30]
     >>> ud = mapclassify.UserDefined(cal, bins)
-    >>> list(ud.bins)
+    >>> ud.bins.tolist()
     [20.0, 30.0, 4111.45]
 
-    >>> list(ud.counts)
+    >>> ud.counts.tolist()
     [37, 4, 17]
 
     Notes
@@ -2537,7 +2548,7 @@ class UserDefined(MapClassifier):
                 "Mapclassify.plot depends on matplotlib.pyplot, and this was"
                 "not able to be imported. \nInstall matplotlib to"
                 "plot spatial classifier."
-            )
+            ) from None
         if ax is None:
             f = plt.figure()
             ax = plt.gca()
@@ -2606,7 +2617,7 @@ class MaxP(MapClassifier):
     >>> mp.bins
     array([3.16000e+00, 1.26300e+01, 1.67000e+01, 2.04700e+01, 4.11145e+03])
 
-    >>> list(mp.counts)
+    >>> mp.counts.tolist()
     [18, 16, 3, 1, 20]
 
     """
@@ -2690,11 +2701,11 @@ class MaxP(MapClassifier):
             rseeds = np.random.permutation(list(range(k))).tolist()
             total_moves = 0
             while rseeds:
-                id = rseeds.pop()
+                _id = rseeds.pop()
                 growing = True
                 total_moves = 0
                 while growing:
-                    target = classes[id]
+                    target = classes[_id]
                     left = target[0] - 1
                     right = target[-1] + 1
                     n_moves = 0
@@ -2705,7 +2716,7 @@ class MaxP(MapClassifier):
                             if self._swap(left_class, target, a):
                                 target.insert(0, a)
                                 left_class.remove(a)
-                                a2c[a] = id
+                                a2c[a] = _id
                                 n_moves += 1
                     if right in a2c:
                         right_class = classes[a2c[right]]
@@ -2715,7 +2726,7 @@ class MaxP(MapClassifier):
                                 target.append(a)
                                 right_class.remove(a)
                                 n_moves += 1
-                                a2c[a] = id
+                                a2c[a] = _id
                     if not n_moves:
                         growing = False
                 total_moves += n_moves
@@ -2744,10 +2755,8 @@ class MaxP(MapClassifier):
         ss1 = self._ss(class1c)
         ss2 = self._ss(class2c)
         tss2 = ss1 + ss2
-        if tss1 < tss2:
-            return False
-        else:
-            return True
+
+        return False if tss1 < tss2 else True  # noqa SIM211
 
 
 def _fit(y, classes):
@@ -2816,7 +2825,7 @@ def gadf(y, method="Quantiles", maxk=15, pct=0.8):
     >>> qgadf[0]
     15
 
-    >>> qgadf[-1]
+    >>> float(qgadf[-1])
     0.3740257590909283
 
     Quantiles fail to exceed 0.80 before 15 classes. If we lower the bar to
@@ -2826,7 +2835,7 @@ def gadf(y, method="Quantiles", maxk=15, pct=0.8):
     >>> qgadf2[0]
     5
 
-    >>> qgadf2[-1]
+    >>> float(qgadf2[-1])
     0.21710231966462412
 
     Notes
@@ -2859,7 +2868,7 @@ def gadf(y, method="Quantiles", maxk=15, pct=0.8):
     return (k, cl, gadf)
 
 
-class KClassifiers(object):
+class KClassifiers:
     """
     Evaluate all :math:`k`-classifers and pick optimal based on :math:`k` and *GADF*.
 
@@ -2892,7 +2901,7 @@ class KClassifiers(object):
     >>> ks.best.k
     4
 
-    >>> ks.best.gadf
+    >>> float(ks.best.gadf)
     0.8481032719908105
 
     Notes
